#ifndef INITIO_H
#define INITIO_H

#include <linux/config.h>
#include <linux/pci.h>
#include <linux/ide.h>

#include <asm/io.h>

#define DISPLAY_INITIO_TIMINGS

#undef initio_VIRTUAL_DMAPIO
#undef initio_BUFFERED_TASKFILE
#undef initio_LARGE_DMA


#if defined(DISPLAY_INITIO_TIMINGS) && defined(CONFIG_PROC_FS)
#include <linux/stat.h>
#include <linux/proc_fs.h>

//==========================
// Register Name Definitios
//==========================
#define ALTSTAT		0x08
#define INTSTAT		0x09
#define MINTSTAT	0x0A
#define PRDCTL		0x0B
#define PXFRCNT		0x10
#define	IDMCTL		0x14
#define	IDMSTAT		0x16
#define PTQFIFO		0x1C
#define SSTATUS		0x20
#define SERROR		0x24
#define GCTRL		0x7C

//==========================
// Register Bit Definitions
//==========================
#define SOFTRST		0x2000
#define aRSTADM		0x0020	//Reset ADMA
#define aIEN		0x0100	//PCI Channel Interrupt Disable
#define aGO			0x0080	//IDMA go
#define MCHQINT		0x20	//Mask Channel Queue Interrupt
#define MCHUIRQ		0x10	//Mask Channel Unsolicited Interrupt
#define MFTLINT		0x08	//Mask Fatal Error Interrupt
#define MCHCINT		0x04	//Mask Channel Complete Interrupt
#define MCHON		0x02	//Mask SATA Channel on
#define MCHOFF		0x01	//Mask SATA Channel off



static char * print_initio_get_info(char *, struct pci_dev *, int);
static int initio_get_info(char *, char **, off_t, int);

static u8 initio_proc;

static ide_pci_host_proc_t initio_procs[] __initdata = {
	{
		.name		= "Initio",
		.set		= 1,
		.get_info	= initio_get_info,
		.parent		= NULL,
	},
};
#endif /* DISPLAY_INITIO_TIMINGS && CONFIG_PROC_FS */	

static unsigned int init_chipset_initio(struct pci_dev *, const char *);
static void init_iops_initio(ide_hwif_t *);
static void init_hwif_initio(ide_hwif_t *);
static void init_dma_initio(ide_hwif_t *, unsigned long);

ide_startstop_t initio_dma_intr(ide_drive_t *);
static int initio_timer_expiry(ide_drive_t *);

static ide_pci_device_t initio_chipsets[] __devinitdata = {
	{	/* 0 */
		.vendor		= PCI_VENDOR_ID_INIT,
		.device		= PCI_DEVICE_ID_INIT_1622,
		.name		= "Inic1622",
		.init_chipset	= init_chipset_initio,
		.init_iops	= init_iops_initio,
		.init_hwif	= init_hwif_initio,
		.init_dma	= init_dma_initio,
		.channels	= 2,
		.autodma	= AUTODMA,
		.enablebits	= {{0x00,0x00,0x00}, {0x00,0x00,0x00}},
		.bootable	= ON_BOARD,
		.extra		= 0,
	},{
		.vendor		= 0,
		.device		= 0,
		.channels	= 0,
		.bootable	= EOL,
	}
};

#endif /* INITIO_H */
